if (process.env.NODE_ENV !== 'development') {
    require('dotenv').config()
}

import axios from 'axios';
import fs from 'fs';
import path from 'path';
import https from 'https';
import { createTRPCRouter, publicProcedure } from "~/server/api/trpc";
import { supabase } from "../supabase";

const cert = fs.readFileSync(
    path.resolve(process.cwd(), process.env.EFI_CERT || '')
);

const agent = new https.Agent({
    pfx: cert,
    passphrase: ''
})

const credentials = Buffer.from(
    `${process.env.EFI_CLIENT_ID}:${process.env.EFI_CLIENT_SECRET}`
).toString('base64')


export const createChargeRouter = createTRPCRouter({
    createCharge: publicProcedure
        .mutation(async () => {
            const authResponse = await axios({
                method: 'POST',
                url: `${process.env.EFI_ENDPOINT}/oauth/token`,
                headers: {
                    Authorization: `Basic ${credentials}`,
                    'Content-Type': 'application/json',
                },
                httpsAgent: agent,
                data: {
                    grant_type: 'client_credentials'
                }
            });

            const accessToken = await authResponse.data?.access_token;

            const reqEfi =  await axios.create({
                baseURL: process.env.EFI_ENDPOINT,
                httpsAgent: agent,
                headers: {
                    Authorization: `Bearer ${accessToken}`,
                    'Content-Type': 'application/json',
                timeout: 300
                }
            })

            const dataCob = {
                calendario: {
                    expiracao: 3600
                },
                valor: {
                    original: '0.01'
                },
                devedor: {
                    nome: 'jose',
                    cpf: '10830617396',
                },
                chave: 'chave-tirada-por-segurança',
                solicitacaoPagador: 'Cobrança dos serviços prestados.',
            };

            const cobResponse = await reqEfi.post('v2/cob', dataCob);

            const qrcodeResponse = await reqEfi.get(`/v2/loc/${cobResponse.data.loc.id}/qrcode`);
            //console.log(qrcodeResponse.data);

            const { data, error } = await supabase
                .from('MoneyData')
                .insert([{
                    valor: cobResponse.data.valor.original,
                    txid: cobResponse.data.txid,
                    data: cobResponse.data.calendario.criacao,
                    status: cobResponse.data.status,
                    solicitacaoDoPagador: cobResponse.data.solicitacaoPagador,
                },]);
            if (error) {console.log(error)}
            else {console.log(data)}
        
            const webhook = await reqEfi.put(`/v2/webhook/${cobResponse.data.chave}`);
            await reqEfi.get(`/v2/webhook/${cobResponse.data.chave}`);
            console.log(webhook);

            await reqEfi.get(`/v2/`)
            return { qrcodeImage: qrcodeResponse.data.imagemQrcode}
        })
})